# -*- coding: utf-8 -*-
SecretId = "secretId"
SecretKey = "secretKey"
Token = "token"
Region = "region"
Endpoint = "endpoint"
Version = "version"
ServiceVersion = "service_version"
Filter = "filter"
Profile = "profile"
Timeout = "timeout"
Output = "output"
GenerateCliSkeleton = "generate-cli-skeleton"
CliInputJson = "cli-input-json"
CliUnfoldArgument = "cli-unfold-argument"

ENV_SECRET_ID = "TENCENTCLOUD_SECRET_ID"
ENV_SECRET_KEY = "TENCENTCLOUD_SECRET_KEY"
ENV_REGION = "TENCENTCLOUD_REGION"
ENV_TOKEN = "TENCENTCLOUD_TOKEN"

Help = "help"
CliVersion = "version"


ACTION_GLOBAL_OPT = [SecretId, SecretKey, Token, Region, Endpoint, Version, Filter, Profile, Timeout,
                     Output, GenerateCliSkeleton, CliInputJson, CliUnfoldArgument]

